==> doxygen-1.8.1.1.src.tar.xz: doxygen-1.8.1.1/src/header_html.h <==
"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n"
"<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
"<head>\n"
"<meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\"/>\n"
"<meta http-equiv=\"X-UA-Compatible\" content=\"IE=9\"/>\n"
"<!--BEGIN PROJECT_NAME--><title>$projectname: $title</title><!--END PROJECT_NAME-->\n"
"<!--BEGIN !PROJECT_NAME--><title>$title</title><!--END !PROJECT_NAME-->\n"
"<link href=\"$relpath$tabs.css\" rel=\"stylesheet\" type=\"text/css\"/>\n"
"<script type=\"text/javascript\" src=\"$relpath$jquery.js\"></script>\n"
"<script type=\"text/javascript\" src=\"$relpath$dynsections.js\"></script>\n"
"$treeview\n"
"$search\n"
"$mathjax\n"
"<link href=\"$relpath$$stylesheet\" rel=\"stylesheet\" type=\"text/css\" />\n"
"</head>\n"
"<body>\n"
"<div id=\"top\"><!-- do not remove this div, it is closed by doxygen! -->\n"
"\n"
"<!--BEGIN TITLEAREA-->\n"
"<div id=\"titlearea\">\n"
"<table cellspacing=\"0\" cellpadding=\"0\">\n"
" <tbody>\n"
" <tr style=\"height: 56px;\">\n"
"  <!--BEGIN PROJECT_LOGO-->\n"
"  <td id=\"projectlogo\"><img alt=\"Logo\" src=\"$relpath$$projectlogo\"/></td>\n"
"  <!--END PROJECT_LOGO-->\n"
"  <!--BEGIN PROJECT_NAME-->\n"
"  <td style=\"padding-left: 0.5em;\">\n"
"   <div id=\"projectname\">$projectname\n"
"   <!--BEGIN PROJECT_NUMBER-->&#160;<span id=\"projectnumber\">$projectnumber</span><!--END PROJECT_NUMBER-->\n"
"   </div>\n"
"   <!--BEGIN PROJECT_BRIEF--><div id=\"projectbrief\">$projectbrief</div><!--END PROJECT_BRIEF-->\n"
"  </td>\n"
"  <!--END PROJECT_NAME-->\n"
"  <!--BEGIN !PROJECT_NAME-->\n"
"   <!--BEGIN PROJECT_BRIEF-->\n"
"    <td style=\"padding-left: 0.5em;\">\n"
"    <div id=\"projectbrief\">$projectbrief</div>\n"
"    </td>\n"
"   <!--END PROJECT_BRIEF-->\n"
"  <!--END !PROJECT_NAME-->\n"
"  <!--BEGIN DISABLE_INDEX-->\n"
"   <!--BEGIN SEARCHENGINE-->\n"
"   <td>$searchbox</td>\n"
"   <!--END SEARCHENGINE-->\n"
"  <!--END DISABLE_INDEX-->\n"
" </tr>\n"
" </tbody>\n"
"</table>\n"
"</div>\n"
"<!--END TITLEAREA-->\n"
"<!-- end header part -->\n"

==> doxygen-1.8.5.src.tar.xz: doxygen-1.8.5/src/header_html.h <==
"<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Transitional//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd\">\n"
"<html xmlns=\"http://www.w3.org/1999/xhtml\">\n"
"<head>\n"
"<meta http-equiv=\"Content-Type\" content=\"text/xhtml;charset=UTF-8\"/>\n"
"<meta http-equiv=\"X-UA-Compatible\" content=\"IE=9\"/>\n"
"<meta name=\"generator\" content=\"Doxygen $doxygenversion\"/>\n"
"<!--BEGIN PROJECT_NAME--><title>$projectname: $title</title><!--END PROJECT_NAME-->\n"
"<!--BEGIN !PROJECT_NAME--><title>$title</title><!--END !PROJECT_NAME-->\n"
"<link href=\"$relpath^tabs.css\" rel=\"stylesheet\" type=\"text/css\"/>\n"
"<script type=\"text/javascript\" src=\"$relpath^jquery.js\"></script>\n"
"<script type=\"text/javascript\" src=\"$relpath^dynsections.js\"></script>\n"
"$treeview\n"
"$search\n"
"$mathjax\n"
"<link href=\"$relpath^$stylesheet\" rel=\"stylesheet\" type=\"text/css\" />\n"
"$extrastylesheet\n"
"</head>\n"
"<body>\n"
"<div id=\"top\"><!-- do not remove this div, it is closed by doxygen! -->\n"
"\n"
"<!--BEGIN TITLEAREA-->\n"
"<div id=\"titlearea\">\n"
"<table cellspacing=\"0\" cellpadding=\"0\">\n"
" <tbody>\n"
" <tr style=\"height: 56px;\">\n"
"  <!--BEGIN PROJECT_LOGO-->\n"
"  <td id=\"projectlogo\"><img alt=\"Logo\" src=\"$relpath^$projectlogo\"/></td>\n"
"  <!--END PROJECT_LOGO-->\n"
"  <!--BEGIN PROJECT_NAME-->\n"
"  <td style=\"padding-left: 0.5em;\">\n"
"   <div id=\"projectname\">$projectname\n"
"   <!--BEGIN PROJECT_NUMBER-->&#160;<span id=\"projectnumber\">$projectnumber</span><!--END PROJECT_NUMBER-->\n"
"   </div>\n"
"   <!--BEGIN PROJECT_BRIEF--><div id=\"projectbrief\">$projectbrief</div><!--END PROJECT_BRIEF-->\n"
"  </td>\n"
"  <!--END PROJECT_NAME-->\n"
"  <!--BEGIN !PROJECT_NAME-->\n"
"   <!--BEGIN PROJECT_BRIEF-->\n"
"    <td style=\"padding-left: 0.5em;\">\n"
"    <div id=\"projectbrief\">$projectbrief</div>\n"
"    </td>\n"
"   <!--END PROJECT_BRIEF-->\n"
"  <!--END !PROJECT_NAME-->\n"
"  <!--BEGIN DISABLE_INDEX-->\n"
"   <!--BEGIN SEARCHENGINE-->\n"
"   <td>$searchbox</td>\n"
"   <!--END SEARCHENGINE-->\n"
"  <!--END DISABLE_INDEX-->\n"
" </tr>\n"
" </tbody>\n"
"</table>\n"
"</div>\n"
"<!--END TITLEAREA-->\n"
"<!-- end header part -->\n"
